@@ -2,23 +2,18 @@
 
 import os
 import sys
-import argparse
-import re
 import subprocess
 import logging
 from subprocess import PIPE
-import pkg_resources
 import collections
 from datetime import datetime
 from sympy.logic import simplify_logic
-from sympy import symbols
-from cvehound.cpu import CPU
 from cvehound.exception import UnsupportedVersion
 from cvehound.util import get_spatch_version, get_rule_cves, get_cves_metadata, parse_coccinelle_output
 from cvehound.kbuild import KbuildParser
 from cvehound.config import Config
 
-__VERSION__ = '1.1.0'
+__VERSION__ = '1.2.0'
 
 
 class CVEhound:
@@ -27,7 +22,6 @@ class CVEhound:
         kernel = os.path.abspath(kernel)
         self.kernel = kernel
         self.metadata = get_cves_metadata(metadata)
-        self.cocci_job = str(CPU().get_cocci_jobs())
         self.spatch_version = get_spatch_version()
         self.check_strict = check_strict
         self.rules_metadata = {}
@@ -70,6 +64,10 @@ class CVEhound:
             self.config_map = None
             self.config = None
 
+        if self.spatch_version <= 104:
+            logging.warning('spatch (coccinelle) version is too old.\n'
+                            'Please, consider updating to >= 1.0.7 version.')
+
     def get_grep_pattern(self, rule):
         patterns = []
         with open(rule, 'rt') as fh:
@@ -150,27 +148,29 @@ class CVEhound:
                 raise UnsupportedVersion(self.spatch_version, cve, rule_ver)
             try:
                 cocci_cmd = ['spatch', '--no-includes', '--include-headers',
-                             '-D', 'detect', '--no-show-diff', '-j', self.cocci_job,
-                             *includes,
-                             '--chunksize', '1',
-                             '--cocci-file', rule, *files]
+                             '-D', 'detect', '--chunksize', '1', '-j', '1',
+                             '--no-show-diff', '--very-quiet',
+                             *includes]
+                if self.spatch_version > 104: # Not suppored on coccinelle 1.0.4
+                    cocci_cmd.extend(['--python', os.path.realpath(sys.executable)])
+                cocci_cmd.extend(['--cocci-file', rule, *files])
 
                 logging.debug(' '.join(cocci_cmd))
 
-                run = subprocess.run(cocci_cmd, stdout=PIPE, stderr=PIPE, check=True)
-                output = run.stdout.decode('utf-8').strip()
+                run = subprocess.run(cocci_cmd, stdout=PIPE, stderr=PIPE, check=True, universal_newlines=True)
+                output = run.stdout.strip()
             except subprocess.CalledProcessError as e:
-                err = e.stderr.decode('utf-8').split('\n')[-2]
+                err = e.stderr.split('\n')[-2]
                 # Coccinelle 1.0.4 bug workaround
                 if ('Sys_error("' + cve + ': No such file or directory")') not in err:
                     raise e
         else:
             for pattern in self.get_grep_pattern(rule):
                 args = ['grep', '-rPzle', pattern, *files]
-                run = subprocess.run(args, stdout=PIPE, stderr=PIPE, check=False)
+                run = subprocess.run(args, stdout=PIPE, stderr=PIPE, check=False, universal_newlines=True)
                 if run.returncode != 0:
                     break
-                output += run.stdout.decode('utf-8').strip()
+                output += run.stdout.strip()
             else:
                 # Found all patterns
                 output += '\nERROR'
