@@ -6,6 +6,7 @@ import pkg_resources
 import gzip
 import json
 import subprocess
+import ssl
 from urllib.request import urlopen, Request
 from datetime import datetime
 import lxml.etree as etree
@@ -13,11 +14,15 @@ from io import BytesIO
 from zipfile import ZipFile
 
 def get_exploit_status_from_fstec():
+    ctx = ssl.create_default_context()
+    ctx.check_hostname = False
+    ctx.verify_mode = ssl.CERT_NONE
     req = Request('https://bdu.fstec.ru/files/documents/vulxml.zip', headers={'User-Agent': 'Mozilla/5.0'})
-    with urlopen(req) as uh:
+    with urlopen(req, context=ctx) as uh:
         with ZipFile(BytesIO(uh.read())) as zh:
             with zh.open('export/export.xml') as fh:
-                tree = etree.parse(fh)
+                parser = etree.XMLParser(recover=True)
+                tree = etree.parse(fh, parser)
 
     public = set()
     private = set()
@@ -68,6 +73,9 @@ def main(args=sys.argv):
     with urlopen('https://github.com/nluedtke/linux_kernel_cves/raw/master/data/kernel_cves.json') as fh:
         js = json.loads(fh.read().decode('utf-8'))
 
+    # Corrupted data https://github.com/nluedtke/linux_kernel_cves/pull/379
+    js = dict(filter(lambda x: x[0].startswith('CVE-'), js.items()))
+
     for cve, info in js.items():
         fix = info.get('fixes', '')
         if fix and repo:
