@@ -5,6 +5,7 @@ import pkg_resources
 import json
 import gzip
 from shutil import which
+from configparser import ConfigParser
 
 def tool_exists(name):
     return which(name) is not None
@@ -24,18 +25,15 @@ def get_config_data(path):
     return {}
 
 def get_kernel_version(path):
-    version = {}
     with open(os.path.join(path, 'Makefile'), 'rt') as fh:
-        def getparam():
-            line = fh.readline()
-            if line.startswith('#'):
-                line = fh.readline()
-            return line.split('=')[1].strip()
-        version['version'] = getparam()
-        version['patchlevel'] = getparam()
-        version['sublevel'] = getparam()
-        version['extraversion'] = getparam()
-        version['name'] = getparam()
+        makefile = fh.read()
+    version = {}
+    for key in ['version', 'patchlevel', 'sublevel', 'extraversion', 'name']:
+        res = re.search('^' + key.upper() + r'[ \t]*=[ \t]*(.*)[ \t]*$', makefile, re.MULTILINE)
+        if res:
+            version[key] = res.group(1)
+        else:
+            version[key] = ''
     version['full'] = '.'.join([version['version'], version['patchlevel'], version['sublevel']]) + version['extraversion']
     return version
 
@@ -77,9 +75,50 @@ def get_rule_cves():
                 assigned[name] = path
     return (known, assigned, disputed)
 
-def get_cves_metadata():
-    cves = pkg_resources.resource_filename('cvehound', 'data/kernel_cves.json.gz')
+def get_cves_metadata(path):
+    if not path:
+        path = os.environ.get('CVEHOUND_METADATA',
+               pkg_resources.resource_filename('cvehound', 'data/kernel_cves.json.gz'))
     data = None
-    with gzip.open(cves, 'rt', encoding='utf-8') as fh:
+    with gzip.open(path, 'rt', encoding='utf-8') as fh:
         data = json.load(fh)
     return data
+
+def parse_coccinelle_output(output):
+    files = []
+    for line in output.splitlines():
+        file, hline, _ = line.split(':', 2)
+        files.append({
+            'file': file,
+            'line': int(hline),
+        })
+    return files
+
+def parse_config(file):
+    parser = ConfigParser()
+    with open(file, 'rt') as fh:
+        parser.read_string("[cvehound]\n" + fh.read())
+    config = dict(parser['cvehound'])
+
+    for key in ['cve', 'exclude', 'cwe', 'files', 'ignore_files']:
+        if key not in config:
+            continue
+        config[key] = config[key].split()
+
+    if 'verbose' in config:
+        try:
+            config['verbose'] = int(config['verbose'])
+        except ValueError:
+            raise Exception('"verbose" should be an integer')
+
+    for key in ['check_strict', 'all_files', 'exploit']:
+        if key not in config:
+            continue
+        if config[key].lower() in ['y', 't', '1', 'yes', 'true']:
+            config[key] = True
+        elif config[key].lower() in ['n', 'f', '0', 'no', 'false']:
+            config[key] = False
+        else:
+            raise Exception("Can't parse boolean argument " + key)
+
+    return config
