@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 
-import pkg_resources
 import pytest
 import os
 
 from cvehound.exception import UnsupportedVersion
 
+@pytest.mark.slow
 def test_on_fixes(hound, repo, cve):
     fixes = hound.get_rule_fixes(cve)
 
